<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="50%"
            :before-close="handleClose"
        >
            <el-form :model="state.form" size="default" ref="lawRef" :rules="title === '新增' || title === '编辑' ? state.formRules : {}" label-width="110px" >
                <el-form-item label="标题:" prop="title">
                    <el-input v-model.trim="state.form.title" v-if="!isReview" ></el-input>
                    <span v-else>{{state.form.title}}</span>
                </el-form-item>
                <el-form-item label="副标题:" prop="subTitle">
                    <el-input v-model.trim="state.form.subTitle" v-if="!isReview" ></el-input>
                    <span v-else>{{state.form.subTitle}}</span>
                </el-form-item>
                <el-form-item label="类别:" prop="law">
                    <el-radio-group v-model="law" v-if="!isReview" @change="getLawTypeContent">
                        <el-radio :label="1">法律</el-radio>
                        <el-radio :label="2">法规</el-radio>
                        <el-radio :label="3">地方性规定</el-radio>
                        <el-radio :label="4">其他</el-radio>
                    </el-radio-group>
                    <span v-else>{{state.form.lawType}}</span>
                </el-form-item>
                <el-form-item label="颁布机构:" prop="pubAgency">
                    <el-input v-model.trim="state.form.pubAgency" v-if="!isReview" ></el-input>
                    <span v-else>{{state.form.pubAgency}}</span>
                </el-form-item>
                <el-form-item label="颁布日期:" prop="pubDate">
                    <el-date-picker
                        v-if="!isReview"
                        v-model="state.form.pubDate"
                        type="date"
                        value-format="YYYY-MM-DD"
                        placeholder="请选择日期"
                        size="default"
                    />
                    <span v-else>{{state.form.pubDate}}</span>
                </el-form-item>
                <el-form-item label="内容:" v-if="showEditor"  required>
<!--                    <we-editor ref="myEditor"  :propData="state.form.content" @childFn="getEditorData" />-->
                    <t-editor style="width: 800px" ref="myEditor" :value="state.form.content" ></t-editor>
                </el-form-item>
                <el-form-item label="内容:" v-else>
                    <div class="ql-container ql-snow" style="height: 500px;width: 100%;margin-top: 10px;" >
                        <div class="ql-editor">
                            <div v-html="state.form.content" class="reviewTable"  @click="showFile($event)"></div>
                        </div>
                    </div>
                </el-form-item>
            </el-form>
            <template #footer v-if="!isReview">
                    <span class="dialog-footer">
                        <el-button @click="handleClose" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认发布</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import weEditor from "@/components/WeEditor/index.vue";
import TEditor from "@/components/Tinymce/Tinymce.vue"
import {ElMessage} from "element-plus";
import {addLaw, editLaw, getLawDetail} from "@/api/backManage/law";
import axios from "axios";
import {getToken} from "@/utils/auth";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false);
const title = ref("");
const lawRef = ref();
const myEditor = ref();
const isReview = ref(false);
const showEditor = ref(true);
const law = ref(1)
const state = reactive({
    form: {
        id: '',
        title: '',
        subTitle: '',
        content: '',
        lawType: "法律",
        pubAgency: '',
        pubDate: ''

    },
    formRules:{
        title: [{ required: true, message: '请填写标题', trigger: 'blur' }],
        pubAgency: [{ required: true, message: '请填写颁布机构', trigger: 'blur' }],
        // content: [{ required: true, message: '11', trigger: 'blur' }],
        pubDate:[{ required: true, message: '请选择颁布日期', trigger: 'blur' }],
    },

})

const openDialog = async (type, value) => {
    isReview.value = false;
    showEditor.value = false;
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
    if(type === 'edit' || type === 'review') {
        const param = {
            lawId: value.id
        }
        const res = await getLawDetail(param);
        if(res.code === 200){
            state.form = res.data
            if(type === 'edit') {
                law.value = res.data.lawType === '法律' ? 1 : res.data.lawType === '法规' ? 2 :res.data.lawType === '地方性规定'? 3 : 4
            }
            state.form.pubDate = res.data.pubDate.substring(0,10)
        }else{
            ElMessage.warning(res.message)
        }

    }
    if(type === 'add'|| type ==='edit'){
        showEditor.value = true;
        isReview.value = false;
    }
    if(type === 'review') {
        showEditor.value = false;
        isReview.value = true;
    }
    if(type === 'add'){
        reset()
    }
    dialogVisible.value = true;
}
const getEditorData = (val) =>{
    state.form.content = val;
}
const getLawTypeContent = (val) => {
    state.form.lawType = val === 1 ? '法律' : val === 2? '法规' :val === 3?'地方性规定': '其他'
}
const showFile = (e) => {
    if(e.target.nodeName === 'A'){
        console.log("e",e)
        e.preventDefault();
        const file = {
            fileUrl: e.target.href,
            fileName: e.target.download
        }
        axios.get( file.fileUrl,{
                headers:
                    {
                        'Content-Type': 'application/json',
                        'Authorization':getToken(),
                    },
                responseType: 'blob'
            }
        ).then(res=>{
            if (res) {
                const link = document.createElement('a')
                let blob = new Blob([res.data],{type: res.data.type})
                link.style.display = "none";
                link.href = URL.createObjectURL(blob); // 创建URL
                link.setAttribute("download", file.fileName);
                document.body.appendChild(link);
                link.click();
                document.body.removeChild(link);
            } else {
                this.$message.error('获取文件失败')
            }
            // this.handleClose();
        })
    }
}
const onSubmit = async () => {
    state.form.content = tinyMCE.activeEditor.getContent();
    const valid = await lawRef.value.validate();
    if(valid){
        if(state.form.content == "") {
            ElMessage({
                type: 'warning',
                message: '请输入内容'
            });
            return;
        }
        if(title.value === '新增'){
            state.form.pubDate = state.form.pubDate.concat(" 00:00:00")
            state.form.pubDate = state.form.pubDate.substring(0,19)
            const param = {
                content: state.form.content,
                lawType: state.form.lawType,
                pubAgency: state.form.pubAgency,
                pubDate: state.form.pubDate,
                subTitle: state.form.subTitle,
                title: state.form.title
            }
            const res = await addLaw(param)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '新增成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            reset();
            showEditor.value=false
            myEditor.value.clear();
            lawRef.value.clearValidate();
            dialogVisible.value = false;
        }else if(title.value === '编辑') {
            state.form.pubDate = state.form.pubDate.concat(" 00:00:00")
            state.form.pubDate = state.form.pubDate.substring(0,19)
            const res = await editLaw(state.form)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '编辑成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            reset();
            showEditor.value=false
            myEditor.value.clear();
            lawRef.value.clearValidate();
            dialogVisible.value = false;
        }

    }
}

const handleClose = () => {
    if(title.value ==="新增"|| title.value ==='编辑'){
        myEditor.value.clear();
        showEditor.value=false

    }
    lawRef.value.clearValidate();
    dialogVisible.value = false;
}
const reset = () => {
    law.value = 1;
    state.form = {
        id: '',
        title: '',
        subTitle: '',
        content: '',
        lawType: "法律",
        pubAgency: '',
        pubDate: ''
    }
}
defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
.reviewTable {
    :deep(table){
        border: 1px solid #ccc;
        text-align: center;
    }
    :deep(table td){
        border: 1px solid #ccc;
        text-align: center;
        padding: 0 5px;
    }
    :deep(table th){
        border: 1px solid #ccc;
    }
}
</style>
